@@ -60,38 +60,24 @@ function(x, filename="", method="linear", yleft, yright, rule=1, f=0, ties=mean,
 	tr <- blockSize(out)
 	pb <- pbCreate(tr$n, ...)
 	out <- writeStart(out, filename=filename, ...)
-	
-	if (ylr==0) {
-	
-		for (i in 1:tr$n) {
-			v <- getValues(x, row=tr$row[i], nrows=tr$nrows[i])
-			i <- rowSums(is.na(v))
-			i <- i < nl & i > 1 # need at least two
-			if (length(i) > 0 ) {
-				v[i,] <- t( apply(v[i,], 1, function(x) approx(x, xout=xout, method=method, rule=rule, f=f, ties=ties)$y ) )
+
+	for (j in 1:tr$n) {
+		v <- getValues(x, row=tr$row[j], nrows=tr$nrows[j])
+		i <- rowSums(is.na(v))
+		i <- (i < nl) & (i > 1) # need at least two
+		if (length(i) > 0 ) {
+			if (ylr==0) {
+				v[i,] <- t( apply(v[i,], 1, function(x) approx(x=xout, y=x, xout=xout, method=method, rule=rule, f=f, ties=ties)$y ) )
+			} else if (ylr==1) {
+				v[i,] <- t( apply(v[i,], 1, function(x) approx(x=xout, y=x, xout=xout, method=method, yright=yright, rule=rule, f=f, ties=ties)$y ) )
+			} else if (ylr==2) {
+				v[i,] <- t( apply(v[i,], 1, function(x) approx(x=xout, y=x, xout=xout, method=method, yleft=yleft, rule=rule, f=f, ties=ties)$y ) )
+			} else {
+				v[i,] <- t( apply(v[i,], 1, function(x) approx(x=xout, y=x, xout=xout, method=method, yright=yright, yleft=yleft, rule=rule, f=f, ties=ties)$y ) )
 			}
-			out <- writeValues(out, v, tr$row[i])
-			pbStep(pb)
-		}
-		
-	} else {
-	
-		for (i in 1:tr$n) {
-			v <- getValues(x, row=tr$row[i], nrows=tr$nrows[i])
-			i <- rowSums(is.na(v))
-			i <- i < nl & i > 1 # need at least two
-			if (length(i) > 0 ) {
-				if (ylr==1) {
-					v[i,] <- t( apply(v[i,], 1, function(x) approx(x=xout, y=x, xout=xout, method=method, yright=yright, rule=rule, f=f, ties=ties)$y ) )
-				} else if (ylr==2) {
-					v[i,] <- t( apply(v[i,], 1, function(x) approx(x=xout, y=x, xout=xout, method=method, yleft=yleft, rule=rule, f=f, ties=ties)$y ) )
-				} else {
-					v[i,] <- t( apply(v[i,], 1, function(x) approx(x=xout, y=x, xout=xout, method=method, yright=yright, yleft=yleft, rule=rule, f=f, ties=ties)$y ) )
-				}
-			}
-			out <- writeValues(out, v, tr$row[i])
-			pbStep(pb)
 		}
+		out <- writeValues(out, v, tr$row[j])
+		pbStep(pb)
 	}
 	
 	pbClose(pb)
