@@ -1,4 +1,4 @@
-# Author: Robert J. Hijmans, r.hijmans@gmail.com
+# Author: Robert J. Hijmans
 # Date : October 2008
 # Version 0.9
 # Licence GPL v3
@@ -41,10 +41,19 @@ setAs('Raster', 'SpatialPixelsDataFrame',
 		grd <- .getGridTop(r)
 		
 		if (ncol(v) > 2) {
-			SpatialPixelsDataFrame(points=sp, data=data.frame(v[, 3:ncol(v), drop = FALSE], check.names=TRUE), grid=grd)
+			v <- data.frame(v[, 3:ncol(v), drop = FALSE])
+			if (any(is.factor(from))) {
+				f <- levels(from)
+				for (i in 1:length(f)) {
+					if (!is.null(f[[i]])) {
+						v[,i] <- as.factor(f[[i]][v[,i]])
+					}
+				}
+			}
+			SpatialPixelsDataFrame(points=sp, data=v, grid=grd)
 		} else {
-			dat <- data.frame(value=rep(NA, ncol(v)))
-			SpatialPixelsDataFrame(points=sp, data = dat, grid=grd)
+			warning('object has no values, returning a "SpatialPixels" object')
+			SpatialPixelsDataFrame(points=sp, grid=grd)
 		}
 	}
 )
@@ -74,15 +83,8 @@ setAs('Raster', 'SpatialGridDataFrame',
 
 		if (hasValues(from)) {
 		
-			if (nlayers(from) > 1) {
-				sp <- SpatialGridDataFrame(grd, proj4string=crs, data=data.frame(values(from), check.names=TRUE))
-			} else {
-				ln <- layerNames(from)[1]
-				from <- matrix(values(from), ncol=1)
-				colnames(from) <- ln
-				from <- data.frame(from, check.names=TRUE)
-				sp <- SpatialGridDataFrame(grd, proj4string=crs, data=from)
-			}
+			sp <- SpatialGridDataFrame(grd, proj4string=crs, data=as.data.frame(from))
+			
 		} else { 
 			warning('object has no values, returning a "SpatialGrid" object')
 			sp  <- SpatialGrid(grd, proj4string=crs)
@@ -296,7 +298,7 @@ setAs('kasc', 'RasterBrick',
 		}	
 		dim(m) <- dim(from)
 		b <- setValues(b, m)
-		layerNames(b) <- names
+		names(b) <- names
 		return(b)
 	}
 )
@@ -315,12 +317,12 @@ setAs('kasc', 'RasterStack',
 		e <- extent(xmn, xmx, ymn, ymx)
 		r <- raster(e, nrow=nrow, ncol=ncol)
 		r <- setValues(r, as.numeric(from[,1]))
-		layerNames(r) <- names[1]
+		names(r) <- names[1]
 		s <- stack(r)
 		if (ncol(from) > 1) {
 			for (i in 2:ncol(from)) {
 				r <- setValues(r, as.numeric(from[,i]))
-				layerNames(r) <- names[i]
+				names(r) <- names[i]
 				s <- addLayer(s, r)
 			}	
 		}
