@@ -207,7 +207,7 @@ function(x, y, ..., tolerance=0.05, filename="", overlap=TRUE, ext=NULL) {
 	#	tr$nrows <- c(tr$row[-1], nrow(out)+1) - c(tr$row)
 	#	tr$n <- length(tr$row)
 
-		pb <- pbCreate(tr$n, dotargs)
+		pb <- pbCreate(tr$n, dotargs$progress)
 		dotargs$x <- out
 		out <- do.call(writeStart, dotargs)
 		
@@ -331,7 +331,7 @@ function(x, y, ..., tolerance=0.05, filename="", overlap=TRUE, ext=NULL) {
 	#	tr$nrows <- c(tr$row[-1], nrow(out)+1) - c(tr$row)
 	#	tr$n <- length(tr$row)
 
-		pb <- pbCreate(tr$n, dotargs)
+		pb <- pbCreate(tr$n, dotargs$progress)
 		dotargs$x <- out
 		out <- do.call(writeStart, dotargs)
 
