@@ -53,7 +53,7 @@
 	} else {
 		lnams <- gsub(" ", "_", extension(basename(filename), ""))
 	}
-	layerNames(x) <- lnams
+	names(x) <- lnams
 	
 	x@file@name <- filename
 	x@data@min <- minval
