@@ -1,4 +1,4 @@
-# Author: Robert J. Hijmans, r.hijmans@gmail.com
+# Author: Robert J. Hijmans
 # Date :  February 2009
 # Version 0.9
 # Licence GPL v3
@@ -24,7 +24,7 @@ rasterToPoints <- function(x, fun=NULL, spatial=FALSE, ...) {
 		}
 	}
 
-	laynam <- layerNames(x)
+	laynam <- names(x)
 	
 	if (canProcessInMemory(x, 3)) {
 		
@@ -41,30 +41,42 @@ rasterToPoints <- function(x, fun=NULL, spatial=FALSE, ...) {
 		}
 		
 	} else {
+	
 		xyv <- matrix(NA, ncol=2+nlayers(x), nrow=0)
-		colnames(xyv) <- c('x', 'y', layerNames(x))
+		colnames(xyv) <- c('x', 'y', names(x))
 		X <- xFromCol(x, 1:ncol(x))
 		Y <- yFromRow(x, 1:nrow(x))
 
 		tr <- blockSize(x)
 		pb <- pbCreate(tr$n, ...)
 
-		for (i in 1:tr$n) {
-			r <- tr$row[i]:(tr$row[i]+tr$nrows[i]-1)
-			xyvr <- cbind(rep(X, tr$nrows[i]), rep(Y[r], each=ncol(x)), getValues(x, row=tr$row[i], nrows=tr$nrows[i]))
+		if (nl > 1) {
 		
-			notna = apply(xyvr[,3:ncol(xyvr), drop=FALSE], 1, function(z){ sum(is.na(z)) < length(z) })
-			
-			xyvr <- xyvr[notna, ,drop=FALSE]
-			
-			if (!is.null(fun)) {
-				xyvr <- subset(xyvr, fun(xyvr[,3]))
+			for (i in 1:tr$n) {
+				r <- tr$row[i]:(tr$row[i]+tr$nrows[i]-1)
+				xyvr <- cbind(rep(X, tr$nrows[i]), rep(Y[r], each=ncol(x)), getValues(x, row=tr$row[i], nrows=tr$nrows[i]))
+				notna <- rowSums(is.na(xyvr[ , 3:ncol(xyvr), drop=FALSE])) < (ncol(xyvr)-2)
+				xyvr <- xyvr[notna, ,drop=FALSE]
+				xyv <- rbind(xyv, xyvr)
+				pbStep(pb, i)
 			}
-			xyv <- rbind(xyv, xyvr)
 			
-			pbStep(pb, i)
+		} else {
+			# faster
+			for (i in 1:tr$n) {
+				r <- tr$row[i]:(tr$row[i]+tr$nrows[i]-1)
+				v <- getValues(x, row=tr$row[i], nrows=tr$nrows[i])
+				xyvr <- cbind(rep(X, tr$nrows[i]), rep(Y[r], each=ncol(x)), v)
+				xyvr <- subset(xyvr, !is.na(v))
+				if (!is.null(fun)) {
+					xyvr <- subset(xyvr, fun(xyvr[,3]))
+				}
+				xyv <- rbind(xyv, xyvr)
+				pbStep(pb, i)
+			}
 		}
 		pbClose(pb)
+		
 	}
 	
 	if (spatial) {
