@@ -25,7 +25,11 @@ function(x, filename, options=NULL, format, ...) {
 	if (trim(filename) == '') { 
 		filename <- rasterTmpFile() 
 	}
-	filename <- .fullFilename(filename)
+	filename <- .fullFilename(filename, expand=TRUE)
+	if (!file.exists(dirname(filename))) {
+		stop("Attempting to write a file to a path that does not exist:\n  ", dirname(filename))
+	}
+	
 	filetype <- .filetype(format=format, filename=filename)
 	filename <- .getExtension(filename, filetype)
 	if (filetype=='ascii') { 
@@ -47,7 +51,7 @@ function(x, filename, options=NULL, format, ...) {
 	if (trim(filename) == '') { 
 		filename <- rasterTmpFile() 
 	}
-	filename <- .fullFilename(filename)
+	filename <- .fullFilename(filename, expand=TRUE)
 	filetype <- .filetype(format=format, filename=filename)
 	filename <- .getExtension(filename, filetype)
 	
